searchData={"items":[{"type":"module","title":"Emoshi","doc":"Library for accessing the emoji data set.\n\nOnly fully qualified emojis (see https://www.unicode.org/reports/tr51/#def_fully_qualified_emoji)\nare included.\n\nSee https://www.unicode.org/reports/tr51/ for information about emojis.","ref":"Emoshi.html"},{"type":"function","title":"Emoshi.closest/2","doc":"Returns the closest emojis by slug.\n\nUses `String.jaro_distance/2` internally to find the closest emojis.","ref":"Emoshi.html#closest/2"},{"type":"function","title":"Options - Emoshi.closest/2","doc":"* `:ignore_variations` - `t:boolean/0`. Whether to ignore variations such as skin color.\n  Defaults to `true`.\n* `:take`- `t:pos_integer/0`. The number of emojis to retrieve.\n  Defaults to `5`","ref":"Emoshi.html#closest/2-options"},{"type":"function","title":"Examples - Emoshi.closest/2","doc":"iex> Emoshi.closest(\"tumbs up\", take: 2)\n    [\n      %Emoshi{\n        slug: \"thumbs-up\",\n        name: \"thumbs up\",\n        status: :fully_qualified,\n        emoji: \"👍\",\n        group: \"People & Body\",\n        subgroup: \"hand-fingers-closed\"\n      },\n      %Emoshi{\n        slug: \"thumbs-down\",\n        name: \"thumbs down\",\n        status: :fully_qualified,\n        emoji: \"👎\",\n        group: \"People & Body\",\n        subgroup: \"hand-fingers-closed\"\n      }\n    ]","ref":"Emoshi.html#closest/2-examples"},{"type":"function","title":"Emoshi.codepoints/1","doc":"Returns the codepoints for an emoji.","ref":"Emoshi.html#codepoints/1"},{"type":"function","title":"Examples - Emoshi.codepoints/1","doc":"iex> Emoshi.codepoints(\"*️⃣\")\n    \"002A FE0F 20E3\"\n\n    iex> Emoshi.codepoints(\"😌\")\n    \"1F60C\"","ref":"Emoshi.html#codepoints/1-examples"},{"type":"function","title":"Emoshi.emoji?/1","doc":"Returns whether a string is a single emoji","ref":"Emoshi.html#emoji?/1"},{"type":"function","title":"Examples - Emoshi.emoji?/1","doc":"iex> Emoshi.emoji?(\"❤️‍🔥\")\n    true\n\n    iex> Emoshi.emoji?(\"a🫨\")\n    false","ref":"Emoshi.html#emoji?/1-examples"},{"type":"type","title":"Emoshi.emoji_status/0","doc":"","ref":"Emoshi.html#t:emoji_status/0"},{"type":"function","title":"Emoshi.find_by_emoji/1","doc":"Returns the `t:Emoshi.t/0` struct from the emoji character.","ref":"Emoshi.html#find_by_emoji/1"},{"type":"function","title":"Examples - Emoshi.find_by_emoji/1","doc":"iex> Emoshi.find_by_emoji(\"🥶\")\n    %Emoshi{\n      name: \"cold face\",\n      status: :fully_qualified,\n      group: \"Smileys & Emotion\",\n      slug: \"cold-face\",\n      emoji: \"🥶\",\n      subgroup: \"face-unwell\"\n    }\n\n    iex> Emoshi.find_by_emoji(\"not an emoji\")\n    nil","ref":"Emoshi.html#find_by_emoji/1-examples"},{"type":"function","title":"Emoshi.for_group/1","doc":"Returns all emojis for the given group.","ref":"Emoshi.html#for_group/1"},{"type":"function","title":"Emoshi.for_groups/1","doc":"Returns all emojis for the given groups.","ref":"Emoshi.html#for_groups/1"},{"type":"function","title":"Emoshi.for_subgroups/2","doc":"Returns all emojis for the given group and subgroup(s).\n\nAccepts both a single subgroup and a list of subgroups.","ref":"Emoshi.html#for_subgroups/2"},{"type":"function","title":"Examples - Emoshi.for_subgroups/2","doc":"iex> Emoshi.for_subgroups(\"Smileys & Emotion\", \"face-hat\") |> Enum.map(& &1.emoji)\n    [\"🤠\", \"🥳\", \"🥸\"]\n\n    iex> Emoshi.for_subgroups(\"Smileys & Emotion\", [\"face-hat\", \"face-glasses\"]) |> Enum.map(& &1.emoji)\n    [\"🤠\", \"🥳\", \"🥸\", \"😎\", \"🤓\", \"🧐\"]","ref":"Emoshi.html#for_subgroups/2-examples"},{"type":"function","title":"Emoshi.group?/1","doc":"Returns whether the input is an emoji group, case sensiive and exact match.","ref":"Emoshi.html#group?/1"},{"type":"function","title":"Examples - Emoshi.group?/1","doc":"iex> Emoshi.group?(\"Animals & Nature\")\n    true\n\n    iex> Emoshi.group?(\"animals and nature\")\n    false","ref":"Emoshi.html#group?/1-examples"},{"type":"function","title":"Emoshi.groups/0","doc":"Returns all the emojis' groups","ref":"Emoshi.html#groups/0"},{"type":"function","title":"Emoshi.search/2","doc":"Returns all `t:Emoshi.t/0` where the slug matches the input argument.\nThe function is case insensitive and normalizes whitespaces, tabs, etc. to hyphens.\n\nUnlike `closest/2`, it does not match emojis when there are spelling mistakes.","ref":"Emoshi.html#search/2"},{"type":"function","title":"Options - Emoshi.search/2","doc":"* `:ignore_variations` - `t:boolean/0`. Whether to ignore variations such as skin color.\nDefaults to `true`.\n* `:take` - `t:pos_integer/0`. The maximum number of emojis to retrieve. Keep in mind\nthat unlike `closest/2` which always returns the specified `:take` number, this function\nmay return fewer results if there are not enough matches.\nDefaults to `5`","ref":"Emoshi.html#search/2-options"},{"type":"function","title":"Examples - Emoshi.search/2","doc":"iex> Emoshi.search(\"thumbs up\", take: 1)\n    [\n      %Emoshi{\n        slug: \"thumbs-up\",\n        name: \"thumbs up\",\n        status: :fully_qualified,\n        emoji: \"👍\",\n        group: \"People & Body\",\n        subgroup: \"hand-fingers-closed\"\n      }\n    ]\n\n    iex> Emoshi.search(\"THUMBS-UP\")\n    [\n      %Emoshi{\n        slug: \"thumbs-up\",\n        name: \"thumbs up\",\n        status: :fully_qualified,\n        emoji: \"👍\",\n        group: \"People & Body\",\n        subgroup: \"hand-fingers-closed\"\n      }\n    ]\n\n    iex> Emoshi.search(\"tumbs-up\")\n    []","ref":"Emoshi.html#search/2-examples"},{"type":"function","title":"Emoshi.subgroups/1","doc":"Returns all the subgroups for a group, or `nil` if the group does not exist.","ref":"Emoshi.html#subgroups/1"},{"type":"function","title":"Examples - Emoshi.subgroups/1","doc":"iex> Emoshi.subgroups(\"Flags\")\n    [\"flag\", \"country-flag\", \"subdivision-flag\"]\n\n    iex> Emoshi.subgroups(\"flags\")\n    nil","ref":"Emoshi.html#subgroups/1-examples"},{"type":"type","title":"Emoshi.t/0","doc":"","ref":"Emoshi.html#t:t/0"},{"type":"function","title":"Emoshi.version/0","doc":"Returns the unicode spec version used to generate the module.","ref":"Emoshi.html#version/0"},{"type":"extras","title":"README","doc":"[![CI](https://github.com/IgnacioGoldchluk/emoshi/actions/workflows/ci.yml/badge.svg)](https://github.com/IgnacioGoldchluk/emoshi/actions/workflows/ci.yml)\n[![License](https://img.shields.io/hexpm/l/emoshi.svg)](https://github.com/IgnacioGoldchluk/emoshi/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/emoshi.svg)](https://hex.pm/packages/emoshi)\n[![Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/emoshi)\n\n# Emoshi\n\nElixir library for accessing emojis.\n\nThis library's list of emojis is generated from the official [emoji data set](https://www.unicode.org/Public/emoji/latest/emoji-test.txt)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"Add `emoshi` to your list of dependencies in `mix.exs`:\n```elixir\ndef deps do\n  [\n    {:emoshi, \"~> 0.1.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - README","doc":"","ref":"readme.html#basic-usage"},{"type":"extras","title":"Searching by name - README","doc":"```elixir\niex> Emoshi.search(\"thumbs\", take: 2)\n[\n  %Emoshi{\n    slug: \"thumbs-up\",\n    name: \"thumbs up\",\n    status: :fully_qualified,\n    emoji: \"👍\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  },\n  %Emoshi{\n    slug: \"thumbs-down\",\n    name: \"thumbs down\",\n    status: :fully_qualified,\n    emoji: \"👎\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  }\n]\n```","ref":"readme.html#searching-by-name"},{"type":"extras","title":"Fuzzy search - README","doc":"```elixir\niex> Emoshi.closest(\"tubms up\", take: 1)\n[\n  %Emoshi{\n    slug: \"thumbs-up\",\n    name: \"thumbs up\",\n    status: :fully_qualified,\n    emoji: \"👍\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  }\n]\n```","ref":"readme.html#fuzzy-search"},{"type":"extras","title":"Query by group and subgroups - README","doc":"```elixir\niex> Emoshi.for_subgroups(\"Travel & Places\", \"hotel\")\n[\n  %Emoshi{\n    slug: \"bellhop-bell\",\n    name: \"bellhop bell\",\n    status: :fully_qualified,\n    emoji: \"🛎️\",\n    group: \"Travel & Places\",\n    subgroup: \"hotel\"\n  },\n  %Emoshi{\n    slug: \"luggage\",\n    name: \"luggage\",\n    status: :fully_qualified,\n    emoji: \"🧳\",\n    group: \"Travel & Places\",\n    subgroup: \"hotel\"\n  }\n]\n```","ref":"readme.html#query-by-group-and-subgroups"},{"type":"extras","title":"Validation - README","doc":"```elixir\niex> Emoshi.emoji(\"❤️‍🔥\")\ntrue\n\niex> Emoshi.emoji(\"hi\")\nfalse\n```\n\nRefer to the [full documentation](https://hexdocs.pm/emoshi) for a more comprehensive description of the library's functionality","ref":"readme.html#validation"},{"type":"extras","title":"Design and contributing - README","doc":"The main goal of this library is to provide the parsed emoji dataset as an Elixir package.\n\nThe approach of including the raw data set (either as text, json, or any format) and parsing it during runtime or during module compilation brings unnecessary dependencies and slows down application startup or application compilation times. This package aims to be as light as possible and currently contains no dependencies for production usage.\n\nThe reason to place the data module separately from the functionality module is simply to keep it IDE-friendly, since working on the main [`Emoshi`](https://github.com/IgnacioGoldchluk/emoshi/blob/main/lib/emoshi.ex) module while having the entire emoji dataset in the same file would be slow and a poor developer experience.","ref":"readme.html#design-and-contributing"},{"type":"extras","title":"Code generation - README","doc":"The full emoji dataset is downloaded from the official source via [`mix download_emojis`](https://github.com/IgnacioGoldchluk/emoshi/blob/main/tasks/download_emojis.ex). The file is then parsed and the data module is generated at [`Emoshi.Emoshis`](https://github.com/IgnacioGoldchluk/emoshi/blob/main/lib/emoshi/emoshis.ex) via [`mix generate_emojis`](https://github.com/IgnacioGoldchluk/emoshi/blob/main/tasks/generate_emojis.ex). An alias is available to run these 2 tasks as `mix download_and_generate`.","ref":"readme.html#code-generation"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"0.1.2 [2025-04-06] - CHANGELOG","doc":"* Add `Emoshi.emoji?/1`","ref":"changelog.html#0-1-2-2025-04-06"},{"type":"extras","title":"0.1.1 [2025-04-06] - CHANGELOG","doc":"* Add `Emoshi.codepoints/1`\n* Add `Emoshi.find_by_emoji/1`","ref":"changelog.html#0-1-1-2025-04-06"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}